@@ -29,9 +29,9 @@ class RunScriptAssistant : public Cantor::Assistant
     RunScriptAssistant( QObject* parent, QList<QVariant> args );
     ~RunScriptAssistant();
 
-    void initActions();
+    void initActions() Q_DECL_OVERRIDE;
     
-    QStringList run(QWidget* parentt);
+    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
     
 };
 
