@@ -39,16 +39,16 @@ class CANTOR_EXPORT PythonSession : public Cantor::Session
     PythonSession(Cantor::Backend* backend);
     ~PythonSession();
 
-    void login();
-    void logout();
+    void login() Q_DECL_OVERRIDE;
+    void logout() Q_DECL_OVERRIDE;
 
-    void interrupt();
+    void interrupt() Q_DECL_OVERRIDE;
     void runExpression(PythonExpression* expr);
 
-    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave);
-    Cantor::CompletionObject* completionFor(const QString& command, int index=-1);
-    virtual QSyntaxHighlighter* syntaxHighlighter(QObject* parent);
-    virtual QAbstractItemModel* variableModel();
+    Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave) Q_DECL_OVERRIDE;
+    Cantor::CompletionObject* completionFor(const QString& command, int index=-1) Q_DECL_OVERRIDE;
+    QSyntaxHighlighter* syntaxHighlighter(QObject* parent) Q_DECL_OVERRIDE;
+    QAbstractItemModel* variableModel() Q_DECL_OVERRIDE;
 
     virtual bool integratePlots() const = 0;
     virtual QStringList autorunScripts() const = 0;
